darkhistory.electrons.ics.nonrel_diff_terms.Q — DarkHistory documentation

# darkhistory.electrons.ics.nonrel_diff_terms.Q

`darkhistory.electrons.ics.nonrel_diff_terms.` `Q`(beta, photeng, T, as_pairs=False)

  Computes the Q term.

  This term is used in the beta expansion method for computing the nonrelativistic ICS spectrum.

  Parameters: | beta : ndarray Velocity of the electron. photeng : ndarray Secondary photon energy. T : float CMB temperature as_pairs : bool, optional If true, treats eleceng and photeng as a paired list: produces eleceng.size == photeng.size values. Otherwise, gets the spectrum at each photeng for each eleceng, returning an array of length eleceng.size*photeng.size.
  Returns: | ndarray The Q term.

#### Previous topic

darkhistory.electrons.ics.nonrel_diff_terms.H_and_G

#### Next topic

darkhistory.electrons.ics.nonrel_diff_terms.Q_and_K

### This Page

Show Source